==> pipewire-docs-1%3A0.3.80-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__debug.js <==
var group__spa__debug =
[
    [ "buffer.h", "debug_2buffer_8h.html", null ],
    [ "context.h", "spa_2include_2spa_2debug_2context_8h.html", null ],
    [ "dict.h", "debug_2dict_8h.html", null ],
    [ "format.h", "debug_2format_8h.html", null ],
    [ "log.h", "spa_2include_2spa_2debug_2log_8h.html", null ],
    [ "mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
    [ "node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
    [ "pod.h", "debug_2pod_8h.html", null ],
    [ "types.h", "types_8h.html", null ],
    [ "spa_debug_context", "structspa__debug__context.html", [
      [ "log", "structspa__debug__context.html#a5d5a27395a63043da36af7b1289cc711", null ]
    ] ],
    [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", [
      [ "ctx", "structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a", null ],
      [ "log", "structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685", null ],
      [ "level", "structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f", null ],
      [ "topic", "structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2", null ],
      [ "file", "structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7", null ],
      [ "line", "structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338", null ],
      [ "func", "structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724", null ]
    ] ],
    [ "spa_debugn", "group__spa__debug.html#ga20c14faa56c9f91aaccbc7b78bee4d75", null ],
    [ "spa_debug", "group__spa__debug.html#ga9df460de860ee08b42581d9846960494", null ],
    [ "spa_debugc", "group__spa__debug.html#ga3f8d824bf3268bbe885154db6a3a5215", null ],
    [ "SPA_LOGF_DEBUG_INIT", "group__spa__debug.html#ga33cb832be355e3f0a39d547fbd005735", null ],
    [ "SPA_LOGT_DEBUG_INIT", "group__spa__debug.html#gad9d0f508b3ec1caafca4e66dc51cd5b5", null ],
    [ "SPA_LOG_DEBUG_INIT", "group__spa__debug.html#ga9d07bf77d70f8ccc9b1254e46a22a243", null ],
    [ "spa_debug_log_pod", "group__spa__debug.html#ga16f96238e59068d1a7637230cb667412", null ],
    [ "spa_debug_log_format", "group__spa__debug.html#ga6f983769067496ffae1b55d9a457384f", null ],
    [ "spa_debug_log_mem", "group__spa__debug.html#gaf6cbda715cf394fce2121122f2f3b9ed", null ],
    [ "spa_debug_log_dict", "group__spa__debug.html#gae1e8aa2eeedd2ccee01c23637d93fefb", null ],
    [ "spa_debugc_buffer", "group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136", null ],
    [ "spa_debug_buffer", "group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139", null ],
    [ "spa_debugc_dict", "group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65", null ],
    [ "spa_debug_dict", "group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602", null ],
    [ "spa_debug_strbuf_format_value", "group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d", null ],
    [ "spa_debug_format_value", "group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe", null ],
    [ "spa_debugc_format", "group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5", null ],
    [ "spa_debug_format", "group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7", null ],
    [ "spa_debug_log_log", "group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339", null ],
    [ "spa_debugc_mem", "group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0", null ],
    [ "spa_debug_mem", "group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca", null ],
    [ "spa_debugc_port_info", "group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9", null ],
    [ "spa_debug_port_info", "group__spa__debug.html#ga26f0007da5add3060d00672939508d55", null ],
    [ "spa_debugc_pod_value", "group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a", null ],
    [ "spa_debugc_pod", "group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb", null ],
    [ "spa_debug_pod_value", "group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506", null ],
    [ "spa_debug_pod", "group__spa__debug.html#ga43da221712a4457ff34457555d39b214", null ],
    [ "spa_debug_type_find", "group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9", null ],
    [ "spa_debug_type_short_name", "group__spa__debug.html#ga894c39341a4e23d74318af04868a71df", null ],
    [ "spa_debug_type_find_name", "group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936", null ],
    [ "spa_debug_type_find_short_name", "group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a", null ],
    [ "spa_debug_type_find_type", "group__spa__debug.html#ga43407166bdc04c3822b66257581fec18", null ],
    [ "spa_debug_type_find_short", "group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954", null ],
    [ "spa_debug_type_find_type_short", "group__spa__debug.html#gac6f960544afa686154bfebae8c42406b", null ]
];

==> pipewire-docs-1%3A1.2.7-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__spa__debug.js <==
var group__spa__debug =
[
    [ "buffer.h", "debug_2buffer_8h.html", null ],
    [ "context.h", "spa_2include_2spa_2debug_2context_8h.html", null ],
    [ "dict.h", "debug_2dict_8h.html", null ],
    [ "file.h", "file_8h.html", null ],
    [ "format.h", "debug_2format_8h.html", null ],
    [ "log.h", "spa_2include_2spa_2debug_2log_8h.html", null ],
    [ "mem.h", "spa_2include_2spa_2debug_2mem_8h.html", null ],
    [ "node.h", "spa_2include_2spa_2debug_2node_8h.html", null ],
    [ "pod.h", "debug_2pod_8h.html", null ],
    [ "types.h", "types_8h.html", null ],
    [ "spa_debug_context", "structspa__debug__context.html", [
      [ "log", "structspa__debug__context.html#af9f0b4808459f1701213a4dbac14601f", null ]
    ] ],
    [ "spa_debug_file_ctx", "structspa__debug__file__ctx.html", [
      [ "ctx", "structspa__debug__file__ctx.html#a817d19045e3261030ec8e38842a018c3", null ],
      [ "f", "structspa__debug__file__ctx.html#a34708c6380f0ca51b9d318a089306401", null ]
    ] ],
    [ "spa_debug_log_ctx", "structspa__debug__log__ctx.html", [
      [ "ctx", "structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a", null ],
      [ "log", "structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685", null ],
      [ "level", "structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f", null ],
      [ "topic", "structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2", null ],
      [ "file", "structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7", null ],
      [ "line", "structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338", null ],
      [ "func", "structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724", null ]
    ] ],
    [ "spa_debugn", "group__spa__debug.html#ga20c14faa56c9f91aaccbc7b78bee4d75", null ],
    [ "spa_debug", "group__spa__debug.html#ga9df460de860ee08b42581d9846960494", null ],
    [ "spa_debugc", "group__spa__debug.html#ga3f8d824bf3268bbe885154db6a3a5215", null ],
    [ "SPA_DEBUG_FILE_INIT", "group__spa__debug.html#ga6b73428f3b72b37ea6034e8502e17916", null ],
    [ "spa_debug_file_error_location", "group__spa__debug.html#ga85b1ea570529cbc197c54ca5d24e18b8", null ],
    [ "SPA_LOGF_DEBUG_INIT", "group__spa__debug.html#ga33cb832be355e3f0a39d547fbd005735", null ],
    [ "SPA_LOGT_DEBUG_INIT", "group__spa__debug.html#gad9d0f508b3ec1caafca4e66dc51cd5b5", null ],
    [ "SPA_LOG_DEBUG_INIT", "group__spa__debug.html#ga9d07bf77d70f8ccc9b1254e46a22a243", null ],
    [ "spa_debug_log_pod", "group__spa__debug.html#ga16f96238e59068d1a7637230cb667412", null ],
    [ "spa_debug_log_format", "group__spa__debug.html#ga6f983769067496ffae1b55d9a457384f", null ],
    [ "spa_debug_log_mem", "group__spa__debug.html#gaf6cbda715cf394fce2121122f2f3b9ed", null ],
    [ "spa_debug_log_dict", "group__spa__debug.html#gae1e8aa2eeedd2ccee01c23637d93fefb", null ],
    [ "spa_debug_log_error_location", "group__spa__debug.html#ga136cf4d2d230a5f6deae8e2b386c3bee", null ],
    [ "spa_debugc_buffer", "group__spa__debug.html#ga95e569a17a18eab8f646974d0b2cc136", null ],
    [ "spa_debug_buffer", "group__spa__debug.html#ga38094276cb4dfb2190710683f4edc139", null ],
    [ "spa_debugc_error_location", "group__spa__debug.html#ga38b44616f32670a7ae1580255fda49e3", null ],
    [ "spa_debugc_dict", "group__spa__debug.html#ga6b44755735f4fdcce858fa6f97594b65", null ],
    [ "spa_debug_dict", "group__spa__debug.html#ga17e8a8e1fb9113f5add80d0b1cfe9602", null ],
    [ "spa_debug_file_log", "group__spa__debug.html#ga182695a55bfbc6aee190ab7c91b5a62b", null ],
    [ "spa_debug_strbuf_format_value", "group__spa__debug.html#gaef7cbb7d8a18d32656a9149cd4fdfd6d", null ],
    [ "spa_debug_format_value", "group__spa__debug.html#gaeec0bfa08b41f3002b60ed2e997cabbe", null ],
    [ "spa_debugc_format", "group__spa__debug.html#ga5eb6d7ec8b97e55331c9297a581800a5", null ],
    [ "spa_debug_format", "group__spa__debug.html#ga0c0aff43e13b4501952801fa3be7b1b7", null ],
    [ "spa_debug_log_log", "group__spa__debug.html#ga8bb3edd099bef82423cee5eff879c339", null ],
    [ "spa_debugc_mem", "group__spa__debug.html#gafaccba3f44098f680e755ad34b421de0", null ],
    [ "spa_debug_mem", "group__spa__debug.html#gae0fd7bbdbaad907ad5b923053f888dca", null ],
    [ "spa_debugc_port_info", "group__spa__debug.html#gafb77a961ae0c0be0034f2a1b4f264ee9", null ],
    [ "spa_debug_port_info", "group__spa__debug.html#ga26f0007da5add3060d00672939508d55", null ],
    [ "spa_debugc_pod_value", "group__spa__debug.html#gac394fa61f7506be415fd8c0b6e422c6a", null ],
    [ "spa_debugc_pod", "group__spa__debug.html#ga3e6c9fbc3e47f47500bf59145a8baadb", null ],
    [ "spa_debug_pod_value", "group__spa__debug.html#gaa00cdef782319e1a9ae738ffb9422506", null ],
    [ "spa_debug_pod", "group__spa__debug.html#ga43da221712a4457ff34457555d39b214", null ],
    [ "spa_debug_type_find", "group__spa__debug.html#ga4b2e0edb1afe21a398be311ab6bde5b9", null ],
    [ "spa_debug_type_short_name", "group__spa__debug.html#ga894c39341a4e23d74318af04868a71df", null ],
    [ "spa_debug_type_find_name", "group__spa__debug.html#ga8907dcd66c24ffc68f2d328111428936", null ],
    [ "spa_debug_type_find_short_name", "group__spa__debug.html#ga8ad92675783ea166fc2ea34dad54b75a", null ],
    [ "spa_debug_type_find_type", "group__spa__debug.html#ga43407166bdc04c3822b66257581fec18", null ],
    [ "spa_debug_type_find_short", "group__spa__debug.html#gac0431ebc7981b41690e6356925bcc954", null ],
    [ "spa_debug_type_find_type_short", "group__spa__debug.html#gac6f960544afa686154bfebae8c42406b", null ]
];
